pub struct SchemaPath { /* private fields */ }Expand description
Path from a root type to a specific location in the schema tree.
Formatted as RootType.field.nested_field or RootType::Variant.field.
Implementations
Sourceimpl SchemaPath
impl SchemaPath
pub fn new() -> Self
Sourcepub fn push_front(&mut self, segment: PathSegment)
pub fn push_front(&mut self, segment: PathSegment)
Prepend a segment to the front of the path.
pub fn with_front(self, segment: PathSegment) -> Self