pub struct TranslationError {
pub path: SchemaPath,
pub kind: Box<TranslationErrorKind>,
}Fields
path: SchemaPathPath from the root type to the error site.
kind: Box<TranslationErrorKind>The specific incompatibility.
Implementations
Sourceimpl TranslationError
impl TranslationError
pub fn new(kind: TranslationErrorKind) -> Self
Sourcepub fn with_path_prefix(self, segment: PathSegment) -> Self
pub fn with_path_prefix(self, segment: PathSegment) -> Self
Prepend a path segment when propagating errors up from nested plan building.